# Written for Joho Kiso A  
# Yoshinori Hayakawa, 2011 
# 2019-02-22: Python version

import math

# defs for nucleotide
NUC_T=1
NUC_U=1
NUC_C=2
NUC_A=3
NUC_G= 4
# defs for amino acid */
AA_A=1
AA_C=2
AA_D=3
AA_E=4
AA_F=5
AA_G=6
AA_H=7
AA_I=8
AA_K=9
AA_L=10
AA_M=11
AA_N=12
AA_P=13
AA_Q=14
AA_R=15
AA_S=16
AA_T=17
AA_V=18
AA_W=19
AA_Y=20
AA_X=(-1) # terminate code

def readGBK(filename):
  fp = open(filename,"r") ;
  if fp is None:
      print("cannot open file:",filename) 
      return 0
  print("reading:",filename)
  n=0
  nucdata=[ ]
  started=False
  for line in fp:
      records = line.split()
      if records[0]=="ORIGIN":
          started = True
          n=0
      elif records[0]=="//":
          started = False
      else:
          if started:
            for i in range(len(line)):
              c = str(line)[i]
              # print(c)
              if c=='a' or c=='A':
                nucdata.append(NUC_A)
                n=n+1
              elif c=='u' or c=='U' or c=='t' or c=='T':
                nucdata.append(NUC_T)
                n=n+1
              elif c=='c' or c=='C':
                nucdata.append(NUC_C)
                n=n+1
              elif c=='g' or c=='G':
                nucdata.append(NUC_G)
                n=n+1
  fp.close
  print(n,"bp")
  return nucdata


def aminoAcid(x, y, z):
  tab=[
    AA_F, AA_F, AA_L, AA_L, AA_S, AA_S, AA_S, AA_S, AA_Y, AA_Y, AA_X, AA_X, AA_C, AA_C, AA_X, AA_W,
    AA_L, AA_L, AA_L, AA_L, AA_P, AA_P, AA_P, AA_P, AA_H, AA_H, AA_Q, AA_Q, AA_R, AA_R, AA_R, AA_R,
    AA_I, AA_I, AA_I, AA_M, AA_T, AA_T, AA_T, AA_T, AA_N, AA_N, AA_K, AA_K, AA_S, AA_S, AA_R, AA_R,
    AA_V, AA_V, AA_V, AA_V, AA_A, AA_A, AA_A, AA_A, AA_D, AA_D, AA_E, AA_E, AA_G, AA_G, AA_G, AA_G]

  k = (x-1)*16 + (y-1)*4 + (z-1)

  if k>=0 and k<64:
    return tab[k]
  else: 
    return 0

def printAminoAcid(x, y, z):
  k = aminoAcid(x,y,z)
  dic={
    AA_A: 'A',
    AA_C: 'C',
    AA_D: 'D',
    AA_E: 'E',
    AA_F: 'F',
    AA_G: 'G',
    AA_H: 'H',
    AA_I: 'I',
    AA_K: 'K',
    AA_L: 'L',
    AA_M: 'M',
    AA_N: 'N',
    AA_P: 'P',
    AA_Q: 'Q',
    AA_R: 'R',
    AA_S: 'S',
    AA_T: 'T',
    AA_V: 'V',
    AA_W: 'W',
    AA_Y: 'Y',
    AA_X: 'x',
    }
  
  if k in dic.keys():
    print(dic[k],sep="",end="")
  else:
    print('?',sep="",end="")


def printNuc(nucdata):
  for c in nucdata:
    if c==NUC_A:
      print("A",sep="",end="") 
    elif c==NUC_T:
      print("T",sep="",end="") 
    elif c==NUC_C:
      print("C",sep="",end="") 
    elif c==NUC_G:
      print("G",sep="",end="") 
  print("")

def printTriplet(x, y, z):
  trip=[x,y,z]
  for c in trip:
    if c==NUC_A:
      print("A",sep="",end="")
    elif c==NUC_T:
      print("T",sep="",end="")
    elif c==NUC_C:
      print("C",sep="",end="")
    elif c==NUC_G:
      print("G",sep="",end="")
